@@ -2,11 +2,12 @@
 # DATABASE CONNECTION AND QUERIES
 #
 
+from typing import Any
 from anodb import DB  # type: ignore
 from FlaskSimpleAuth import Reference, Flask, Response  # type: ignore
 
 # this reference will behave as a DB
-db = Reference()
+db : Any = Reference()
 
 
 # always commit
